==> haskell-uri-bytestring-0.3.3.1-267-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring
version:              0.3.3.1
visibility:           public
id:                   uri-bytestring-0.3.3.1-AGh4B0Di02NCub4y9gCGUa
key:                  uri-bytestring-0.3.3.1-AGh4B0Di02NCub4y9gCGUa
license:              BSD-3-Clause
copyright:            Soostone Inc.
maintainer:           Michael Xavier <michael.xavier@soostone.com>
author:               Doug Beardsley, Michael Xavier
homepage:             https://github.com/Soostone/uri-bytestring
synopsis:             Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.

category:             Web
abi:                  a403da992a40ab242955602f5e2d0dfe
exposed:              True
exposed-modules:      URI.ByteString URI.ByteString.QQ
hidden-modules:
    URI.ByteString.Lens URI.ByteString.Types URI.ByteString.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring
hs-libraries:         HSuri-bytestring-0.3.3.1-AGh4B0Di02NCub4y9gCGUa
depends:
    attoparsec-0.14.4-IxPlyKeM7RE2Q1eOkxwOEV base-4.17.2.1
    blaze-builder-0.4.4-6pj5g3cSiSiJX9apPPZfOV bytestring-0.11.5.3
    containers-0.6.7 template-haskell-2.19.0.0
    th-lift-instances-0.1.20-9i3cIWH65p34ljKJkYQ4Cx

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uri-bytestring-0.3.3.1-268-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-uri-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 uri-bytestring
version:              0.3.3.1
visibility:           public
id:                   uri-bytestring-0.3.3.1-LOBJrtZ0gah7XW774dnn7s
key:                  uri-bytestring-0.3.3.1-LOBJrtZ0gah7XW774dnn7s
license:              BSD-3-Clause
copyright:            Soostone Inc.
maintainer:           Michael Xavier <michael.xavier@soostone.com>
author:               Doug Beardsley, Michael Xavier
homepage:             https://github.com/Soostone/uri-bytestring
synopsis:             Haskell URI parsing as ByteStrings
description:
    uri-bytestring aims to be an RFC3986 compliant URI parser that uses efficient ByteStrings for parsing and representing the URI data.

category:             Web
abi:                  601a630feb43a4d93763ed885dee13e1
exposed:              True
exposed-modules:      URI.ByteString URI.ByteString.QQ
hidden-modules:
    URI.ByteString.Lens URI.ByteString.Types URI.ByteString.Internal

import-dirs:          /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/uri-bytestring-0.3.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-uri-bytestring
hs-libraries:         HSuri-bytestring-0.3.3.1-LOBJrtZ0gah7XW774dnn7s
depends:
    attoparsec-0.14.4-IxPlyKeM7RE2Q1eOkxwOEV base-4.17.2.1
    blaze-builder-0.4.4.1-Fu0lIXvNfl2GZl8eSsy5LD bytestring-0.11.5.3
    containers-0.6.7 template-haskell-2.19.0.0
    th-lift-instances-0.1.20-9i3cIWH65p34ljKJkYQ4Cx

haddock-interfaces:
    /usr/share/doc/haskell-uri-bytestring/html/uri-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-uri-bytestring/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
